==> klayout-0.14.tar.gz: klayout-0.14/src/gsiDeclDbShapes.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "gsi.h"
#include "dbShapes.h"
#include "dbShape.h"
#include "dbCellGraph.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::Shapes binding

template<class Sh>
static void insert (db::Shapes *s, const Sh &p)
{
  s->insert (p);
}

template<class Sh>
static void insert_with_properties (db::Shapes *s, const Sh &p, db::PropertiesRepository::properties_id_type id)
{
  s->insert (db::shape_with_properties<Sh> (p, id));
}

static db::Shapes::shape_iterator begin (const db::Shapes *s, unsigned int flags)
{
  return s->begin (flags);
}

static unsigned int s_all ()                 { return db::ShapeIterator::All; }
static unsigned int s_all_with_properties () { return db::ShapeIterator::AllWithProperties; }
static unsigned int s_properties ()          { return db::ShapeIterator::Properties; }
static unsigned int s_polygons ()            { return db::ShapeIterator::Polygons; }
static unsigned int s_boxes ()               { return db::ShapeIterator::Boxes; }
static unsigned int s_edges ()               { return db::ShapeIterator::Edges; }
static unsigned int s_paths ()               { return db::ShapeIterator::Paths; }
static unsigned int s_texts ()               { return db::ShapeIterator::Texts; }
static unsigned int s_user_objects ()        { return db::ShapeIterator::UserObjects; }

template <>
Class<db::Shapes> Class<db::Shapes>::decl ("Shapes", 
  //  HINT: clear() is not exported. Because of dirty bbox management, clear() must be called from the cell 
  //  using the layer index to reference it.
  gsi::method_ext ("insert_box", &insert<db::Box>,
    "@brief Insert a box into the shapes list\n"
    "@args box"
  ) +
  gsi::method_ext ("insert_path", &insert<db::Path>,
    "@brief Insert a path into the shapes list\n"
    "@args path"
  ) +
  gsi::method_ext ("insert_edge", &insert<db::Edge>,
    "@brief Insert a edge into the shapes list\n"
    "@args edge"
  ) +
  gsi::method_ext ("insert_text", &insert<db::Text>,
    "@brief Insert a text into the shapes list\n"
    "@args text"
  ) +
  gsi::method_ext ("insert_simple_polygon", &insert<db::SimplePolygon>,
    "@brief Insert a simple polygon into the shapes list\n"
    "@args simple_polygon"
  ) +
  gsi::method_ext ("insert_polygon", &insert<db::Polygon>,
    "@brief Insert a polygon into the shapes list\n"
    "@args polygon"
  ) +
  gsi::method_ext ("insert_box_with_properties", &insert_with_properties<db::Box>,
    "@brief Insert a box with properties into the shapes list\n"
    "@args box, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert_path_with_properties", &insert_with_properties<db::Path>,
    "@brief Insert a path with properties into the shapes list\n"
    "@args path, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert_edge_with_properties", &insert_with_properties<db::Edge>,
    "@brief Insert a edge with properties into the shapes list\n"
    "@args edge, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert_text_with_properties", &insert_with_properties<db::Text>,
    "@brief Insert a text with properties into the shapes list\n"
    "@args text, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert_simple_polygon_with_properties", &insert_with_properties<db::SimplePolygon>,
    "@brief Insert a simple polygon with properties into the shapes list\n"
    "@args simple_polygon, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert_polygon_with_properties", &insert_with_properties<db::Polygon>,
    "@brief Insert a polygon with properties into the shapes list\n"
    "@args polygon, property_id\n"
    "The property Id must be obtained from the properties \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::iterator_ext ("each", &begin, 
    "@brief Iterate all shapes \n"
    "@args flags\n"
    "\n"
    "@param flags An \"or\"-ed combination of the s_... constants\n"
  ) +
  gsi::method ("s_all", &s_all) +
  gsi::method ("s_all_with_properties", &s_all_with_properties) +
  gsi::method ("s_polygons", &s_polygons) +
  gsi::method ("s_boxes", &s_boxes) +
  gsi::method ("s_edges", &s_edges) +
  gsi::method ("s_paths", &s_paths) +
  gsi::method ("s_texts", &s_texts) +
  gsi::method ("s_user_objects", &s_user_objects) +
  gsi::method ("s_properties", &s_properties),
  "@brief A collection of shapes\n"
  "\n"
  "A shapes collection is a collection of geometrical objects, such as polygons, boxes, paths, edges or text objects.\n"
);

}

==> klayout-0.15.tar.gz: klayout-0.15/src/gsiDeclDbShapes.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "gsi.h"
#include "dbShapes.h"
#include "dbShape.h"
#include "dbCellGraph.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::Shapes binding

template<class Sh>
static void insert (db::Shapes *s, const Sh &p)
{
  s->insert (p);
}

template<class Sh>
static void insert_with_properties (db::Shapes *s, const Sh &p, db::PropertiesRepository::properties_id_type id)
{
  s->insert (db::object_with_properties<Sh> (p, id));
}

static db::Shapes::shape_iterator begin (const db::Shapes *s, unsigned int flags)
{
  return s->begin (flags);
}

static unsigned int s_all ()                 { return db::ShapeIterator::All; }
static unsigned int s_all_with_properties () { return db::ShapeIterator::AllWithProperties; }
static unsigned int s_properties ()          { return db::ShapeIterator::Properties; }
static unsigned int s_polygons ()            { return db::ShapeIterator::Polygons; }
static unsigned int s_boxes ()               { return db::ShapeIterator::Boxes; }
static unsigned int s_edges ()               { return db::ShapeIterator::Edges; }
static unsigned int s_paths ()               { return db::ShapeIterator::Paths; }
static unsigned int s_texts ()               { return db::ShapeIterator::Texts; }
static unsigned int s_user_objects ()        { return db::ShapeIterator::UserObjects; }

template <>
Class<db::Shapes> Class<db::Shapes>::decl ("Shapes", 
  //  HINT: clear() is not exported. Because of dirty bbox management, clear() must be called from the cell 
  //  using the layer index to reference it.
  gsi::method_ext ("insert|#insert_box", &insert<db::Box>,
    "@brief Insert a box into the shapes list\n"
    "@args box"
  ) +
  gsi::method_ext ("insert|#insert_path", &insert<db::Path>,
    "@brief Insert a path into the shapes list\n"
    "@args path"
  ) +
  gsi::method_ext ("insert|#insert_edge", &insert<db::Edge>,
    "@brief Insert a edge into the shapes list\n"
    "@args edge"
  ) +
  gsi::method_ext ("insert|#insert_text", &insert<db::Text>,
    "@brief Insert a text into the shapes list\n"
    "@args text"
  ) +
  gsi::method_ext ("insert|#insert_simple_polygon", &insert<db::SimplePolygon>,
    "@brief Insert a simple polygon into the shapes list\n"
    "@args simple_polygon"
  ) +
  gsi::method_ext ("insert|#insert_polygon", &insert<db::Polygon>,
    "@brief Insert a polygon into the shapes list\n"
    "@args polygon"
  ) +
  gsi::method_ext ("insert|#insert_box_with_properties", &insert_with_properties<db::Box>,
    "@brief Insert a box with properties into the shapes list\n"
    "@args box, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert|#insert_path_with_properties", &insert_with_properties<db::Path>,
    "@brief Insert a path with properties into the shapes list\n"
    "@args path, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert|#insert_edge_with_properties", &insert_with_properties<db::Edge>,
    "@brief Insert a edge with properties into the shapes list\n"
    "@args edge, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert|#insert_text_with_properties", &insert_with_properties<db::Text>,
    "@brief Insert a text with properties into the shapes list\n"
    "@args text, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert|#insert_simple_polygon_with_properties", &insert_with_properties<db::SimplePolygon>,
    "@brief Insert a simple polygon with properties into the shapes list\n"
    "@args simple_polygon, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::method_ext ("insert|#insert_polygon_with_properties", &insert_with_properties<db::Polygon>,
    "@brief Insert a polygon with properties into the shapes list\n"
    "@args polygon, property_id\n"
    "The property Id must be obtained from the \\Layout object's property_id method which "
    "associates a property set with a property Id."
  ) +
  gsi::iterator_ext ("each", &begin, 
    "@brief Iterate all shapes \n"
    "@args flags\n"
    "\n"
    "@param flags An \"or\"-ed combination of the s_... constants\n"
  ) +
  gsi::method ("s_all", &s_all) +
  gsi::method ("s_all_with_properties", &s_all_with_properties) +
  gsi::method ("s_polygons", &s_polygons) +
  gsi::method ("s_boxes", &s_boxes) +
  gsi::method ("s_edges", &s_edges) +
  gsi::method ("s_paths", &s_paths) +
  gsi::method ("s_texts", &s_texts) +
  gsi::method ("s_user_objects", &s_user_objects) +
  gsi::method ("s_properties", &s_properties),
  "@brief A collection of shapes\n"
  "\n"
  "A shapes collection is a collection of geometrical objects, such as polygons, boxes, paths, edges or text objects.\n"
);

}
